package Echiquier;

import Echiquier.Piece.*;

import java.util.concurrent.CancellationException;

/**
 * La simulation de l'echiquier
 */
public class Echiquier {
    public static final int MAXLIG = 8; //nombre max de lignes
    public static final int MAXCOL = 8; //nombre max de colonnes
    private Case[][] table;

    public Echiquier(){
        try {
            echiquierInit();
        }catch (EchiquierException e){}

    }

    //echiquer init
    private void echiquierInit() throws EchiquierException {
        table = new Case[MAXLIG][MAXCOL];

        ColorJoueur colorJoueur = null;
        Piece piece = null;

        for(int lig=0; lig<MAXLIG; lig++) {
            if(lig <= 1){
                colorJoueur = ColorJoueur.NOIR;
            }else {
                colorJoueur = ColorJoueur.BLANCHE;
            }
            for (int col = 0; col < MAXCOL; col++) {
                table[lig][col] = new Case(lig,col);
                //ajouter les pieces dans l'echiquier
                if(lig <= 1 || lig >= 6) {
                    //ajouter les pions
                    if(lig == 1 || lig == 6){
                        piece = new Pion(colorJoueur);
                    }
                    else {
                        //ajouter les tours
                        if(col == 0 || col == 7){
                            piece = new Tour(colorJoueur);
                        }
                        //ajouter les cavaliers
                        if(col == 1 || col == 6){
                            piece = new Cavalier(colorJoueur);
                        }
                        //ajouter les fous
                        if(col == 2 || col == 5){
                            piece = new Fou(colorJoueur);
                        }
                        //ajouter les Dames
                        if(col == 3){
                            piece = new Dame(colorJoueur);
                        }
                        //ajouter les rois
                        if(col == 4){
                            piece = new Roi(colorJoueur);
                        }
                    }

                    table[lig][col].setPiece(piece);
                    table[lig][col].setEchiquier(this);
                }
            }
        }
        System.out.println("L'echiquier init");
    }

    /*
    public Case[] deplaceDisponible(Case depart) throws EchiquierException{
        if(! depart.estEuPiece()) {
            throw new EchiquierException("Le case n'a pas un piece !");
        }
        Case[] disponible = new Case[Echiquier.MAXCOL*Echiquier.MAXLIG];
        int tmpCase = 0;
        for(int lig=0; lig<Echiquier.MAXLIG; lig++){
            for(int col=0; col<Echiquier.MAXCOL; col++){
                if(depart.getPiece().estDpValide(depart, table[lig][col])){
                    disponible[tmpCase++] = table[lig][col];
                }
            }
        }
        return disponible;
    }
    */

    public void deplace(Case[] position) throws EchiquierException {
        //recupperer la Case dans l'echiquier
        Case depart = getCase(position[0]);
        Case arrive = getCase(position[1]);
        if(depart.estEuPiece()) {
            if (depart.getPiece().estDpValide(depart,arrive)) {
                //mettre le piece dans le case
                arrive.setPiece(depart.getPiece());
                depart.setPiece(null);
            } else {
                throw new EchiquierException("Il n'est pas possible de déplacer la pièce en " + depart.toString() + " vers " + arrive.toString() + "!");
            }
        }else {
            throw new EchiquierException("Le case" + depart.toString() +  " n'a pas un piece !");
        }

    }

    public Case[][] getTable() {
        return table;
    }

    public Case getCase(Case unCase){
        return table[unCase.getLig()][unCase.getCol()];
    }

    public Case getCase(int lig, int col){
        return table[lig][col];
    }

    public static void main(String[] argv){
        new IHM(new Echiquier());
    }

}
